//////////////////////////////////////////////////////////////////////////////////
//  Bacis3D.vsh
//  Simple 3D model drawing vertex shader
//
//  Created by Bojan Endrovski on 23/09/2010.
//  Copyright Bojan Endrovski 2010. All rights reserved.
//////////////////////////////////////////////////////////////////////////////////

// Vertex atributes
attribute vec3 a_position;  // Position vertex attribute
attribute vec3 a_normal;    // Normal vertex attribute
attribute vec2 a_texture;   // Texture vertex attribute

// From vertex shader to fragment
// varying vec2 v_position;
varying vec2 v_texture;
varying vec3 v_color;

uniform mat4 u_worldviewproj;   // Premutiplied world-view-projection matrix
uniform mat3 u_normalmatrix;    // Matrix for transorming the normals
uniform vec3 u_lightdir;        // Light direction
uniform vec3 u_ambient;        // Ambient color


void main()
{
	// Expand 
    vec4 pos = u_worldviewproj * vec4(a_position, 1.0);
	gl_Position = pos;
    
    vec3 normal = normalize(u_normalmatrix * a_normal);
    
    float intesity = max(0.0, dot(normal, u_lightdir));
    
    v_color = vec3(intesity, intesity, intesity);
    v_color = max(u_ambient, v_color);
    
    // just pass tex coordinates
    v_texture = a_texture;
}